@@ -111,9 +111,9 @@ class GourdTcp(asyncore.dispatcher, CallBackMgr):
     logger = None
     request_handler_class = None
 
-    def __init__(self, logger_name=None, terminator=None, backlog=None, request_handler_class=None):
+    def __init__(self, logger_name=None, terminator=None, backlog=None, request_handler_class=None, map=None):
         # 把map变成私有的
-        asyncore.dispatcher.__init__(self, map=dict())
+        asyncore.dispatcher.__init__(self, map=dict() if map is None else map)
         CallBackMgr.__init__(self)
         self.logger = logging.getLogger(logger_name or constants.LOGGER_NAME)
         self.terminator = terminator or constants.TERMINATOR
@@ -188,9 +188,9 @@ class GourdUdp(asyncore.dispatcher, CallBackMgr):
     logger = None
     request_handler_class = None
 
-    def __init__(self, logger_name=None, request_handler_class=None):
+    def __init__(self, logger_name=None, request_handler_class=None, map=None):
         # 把map变成私有的
-        asyncore.dispatcher.__init__(self, map=dict())
+        asyncore.dispatcher.__init__(self, map=dict() if map is None else map)
         CallBackMgr.__init__(self)
         self.logger = logging.getLogger(logger_name or constants.LOGGER_NAME)
         self.request_handler_class = request_handler_class or GourdUdpRequestHandler
